@@ -11,7 +11,8 @@ class KafkaProducerManager:
                 {
                     "request.timeout.ms": 20000,
                     "bootstrap.servers": KAFKA_BOOTSTRAP,
-                    "compression.type": "zstd"
+                    "compression.type": "zstd",
+                    "linger.ms": 66,
                 })
 
     def flush_message(self, topic: str, key: str, value):
